@@ -312,19 +312,17 @@ def alist_batch_download(
                 else:
                     headers = {"Range": f"bytes={skipsize}-"}
                     async with async_semaphore:
-                        async with (
-                            aclosing(await client.request(url, "GET", headers=headers, parse=None, async_=True)) as resp, 
-                            async_open(local_path, mode="ab" if skipsize else "wb") as file, 
-                        ):
+                        async with aclosing(await client.request(url, "GET", headers=headers, parse=None, async_=True)) as resp:
                             if (
                                 resp.headers["Content-Type"] == "application/json; charset=utf-8" 
                                 and resp.headers.get("Accept-Range") != "bytes"
                             ):
                                 resp.read()
                                 raise OSError(resp.json())
-                            write = file.write
-                            async for chunk in resp.aiter_bytes(1 << 16):
-                                await write(chunk)
+                            async with async_open(local_path, mode="ab" if skipsize else "wb") as file:
+                                write = file.write
+                                async for chunk in resp.aiter_bytes(1 << 16):
+                                    await write(chunk)
                     logger and logger.info(f"\x1b[1;32mDOWNLOADED\x1b[0m: \x1b[4;34m{local_path!r}\x1b[0m")
                 if sync:
                     seen[local_path[local_local_reldirlen:]] = True
@@ -401,19 +399,17 @@ def alist_batch_download(
                     logger and logger.info(f"\x1b[1;2;32mCREATED\x1b[0m: \x1b[4;34m{local_path!r}\x1b[0m")
                 else:
                     headers = {"Range": f"bytes={skipsize}-"}
-                    with (
-                        closing(client.request(url, "GET", headers=headers, parse=None)) as resp, 
-                        open(local_path, mode="ab" if skipsize else "wb") as file, 
-                    ):
+                    with closing(client.request(url, "GET", headers=headers, parse=None)) as resp:
                         if (
                             resp.headers["Content-Type"] == "application/json; charset=utf-8" 
                             and resp.headers.get("Accept-Range") != "bytes"
                         ):
                             resp.read()
                             raise OSError(resp.json())
-                        write = file.write
-                        for chunk in resp.iter_bytes(1 << 16):
-                            write(chunk)
+                        with open(local_path, mode="ab" if skipsize else "wb") as file:
+                            write = file.write
+                            for chunk in resp.iter_bytes(1 << 16):
+                                write(chunk)
                     logger and logger.info(f"\x1b[1;32mDOWNLOADED\x1b[0m: \x1b[4;34m{local_path!r}\x1b[0m")
                 if sync:
                     seen[local_path[local_local_reldirlen:]] = True
